==> python-nvd3-0.13.5.tar.gz: python-nvd3-0.13.5/setup.py <==
#! /usr/bin/env python
# coding=utf-8

import os
from setuptools import setup, find_packages
from fnmatch import fnmatchcase
from distutils.util import convert_path


def read(*parts):
    return open(os.path.join(os.path.dirname(__file__), *parts)).read()


# Provided as an attribute, so you can append to these instead
# of replicating them:
standard_exclude = ('*.py', '*.pyc', '*$py.class', '*~', '.*', '*.bak')
standard_exclude_directories = ('.*', 'CVS', '_darcs', './build',
                                './dist', 'EGG-INFO', '*.egg-info')


# (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
# Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
# Note: you may want to copy this into your setup.py file verbatim, as
# you can't import this from another package, when you don't know if
# that package is installed yet.
def find_package_data(where='.', package='',
                      exclude=standard_exclude,
                      exclude_directories=standard_exclude_directories,
                      only_in_packages=True,
                      show_ignored=False):
    """
    Return a dictionary suitable for use in ``package_data``
    in a distutils ``setup.py`` file.

    The dictionary looks like::

        {'package': [files]}

    Where ``files`` is a list of all the files in that package that
    don't match anything in ``exclude``.

    If ``only_in_packages`` is true, then top-level directories that
    are not packages won't be included (but directories under packages
    will).

    Directories matching any pattern in ``exclude_directories`` will
    be ignored; by default directories with leading ``.``, ``CVS``,
    and ``_darcs`` will be ignored.

    If ``show_ignored`` is true, then all the files that aren't
    included in package data are shown on stderr (for debugging
    purposes).

    Note patterns use wildcards, or can be exact paths (including
    leading ``./``), and all searching is case-insensitive.
    """

    out = {}
    stack = [(convert_path(where), '', package, only_in_packages)]
    while stack:
        where, prefix, package, only_in_packages = stack.pop(0)
        for name in os.listdir(where):
            fn = os.path.join(where, name)
            if os.path.isdir(fn):
                bad_name = False
                for pattern in exclude_directories:
                    if (fnmatchcase(name, pattern) or fn.lower() == pattern.lower()):
                        bad_name = True
                        if show_ignored:
                            print ("Directory %s ignored by pattern %s" % (fn, pattern))
                        break
                if bad_name:
                    continue
                if (os.path.isfile(os.path.join(fn, '__init__.py')) and not prefix):
                    if not package:
                        new_package = name
                    else:
                        new_package = package + '.' + name
                    stack.append((fn, '', new_package, False))
                else:
                    stack.append((fn, prefix + name + '/', package, only_in_packages))
            elif package or not only_in_packages:
                # is a file
                bad_name = False
                for pattern in exclude:
                    if (fnmatchcase(name, pattern) or fn.lower() == pattern.lower()):
                        bad_name = True
                        if show_ignored:
                            print ("File %s ignored by pattern %s" % (fn, pattern))
                        break
                if bad_name:
                    continue
                out.setdefault(package, []).append(prefix + name)
    return out


setup(
    name='python-nvd3',
    version='0.13.5',
    description="Python NVD3 - Chart Library for d3.js",
    long_description=read('README.rst'),
    keywords='plot, graph, nvd3, d3',
    author='Belaid Arezqui',
    author_email='areski@gmail.com',
    url='http://github.com/areski/python-nvd3',
    license='MIT license',
    py_modules=['nvd3'],
    namespace_packages=[],
    test_suite='tests',
    packages=find_packages(),
    package_data=find_package_data(),
    zip_safe=False,
    install_requires=[
        'setuptools',
        'python-slugify==0.0.9',
        'Jinja2>=2.7.2'
        # -*- Extra requirements: -*-
    ],
    entry_points={
        'console_scripts': [
            'nvd3 = nvd3:_main',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Multimedia :: Graphics :: Presentation',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)

==> python-nvd3-0.14.2.tar.gz: python-nvd3-0.14.2/setup.py <==
#! /usr/bin/env python
# coding=utf-8

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGELOG.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

requirements = [
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='python-nvd3',
    version='0.14.2',
    description="Python NVD3 - Chart Library for d3.js",
    long_description=readme + '\n\n' + history,
    keywords='plot, graph, nvd3, d3',
    author='Belaid Arezqui',
    author_email='areski@gmail.com',
    url='http://github.com/areski/python-nvd3',
    license="MIT",
    py_modules=['nvd3'],
    namespace_packages=[],
    test_suite='tests',
    packages=[
        'nvd3',
    ],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'python-slugify==1.1.4',
        'Jinja2>=2.8'
        # -*- Extra requirements: -*-
    ],
    entry_points={
        'console_scripts': [
            'nvd3 = nvd3.NVD3Chart:_main',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Multimedia :: Graphics :: Presentation',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
